@@ -41,7 +41,7 @@ class QualityChecker(object):
             pd.to_datetime(self._obj[column_name])
             return node.data, True
         except Exception as _:
-            return "Parse error: {0} for {1}".format(node.data, node.children[0]), False
+            return "Date parse error: {0} for {1}".format(node.data, node.children[0]), False
 
     def _apply_has_one_of(self, node) -> Tuple[str, bool]:
         column_name = node.children[0]
@@ -49,6 +49,14 @@ class QualityChecker(object):
         unique_values = self._obj[column_name].unique()
         return node.data, all(elem in allowed_values for elem in unique_values)
 
+    def _apply_value_length(self, node) -> Tuple[str, bool]:
+        column_name = node.children[0]
+        c = node.children[1]
+        rhs = node.children[2]
+        unique_lengths = self._obj[column_name].astype(str).map(len).unique()
+        compare_fn = self._comparator_to_fn(c, rhs)
+        return node.data, len(unique_lengths) == 1 and compare_fn(unique_lengths[0])
+
     def _apply_check(self, check) -> Tuple[str, bool]:
         try:
             c = check[0]
@@ -74,6 +82,8 @@ class QualityChecker(object):
                 return self._apply_quantile(c)
             elif c.data == "is_date":
                 return self._apply_date_validation(c)
+            elif c.data == "value_length":
+                return self._apply_value_length(c)
             else:
                 raise GenieException(f"{c.data} seems to be not implemented in the DSL")
         except KeyError:
@@ -87,16 +97,19 @@ class QualityChecker(object):
                     v = self._apply_check(check.children)
                     results.insert(0, v)
             else:
-                raise SyntaxError('Unknown instruction: %s' % predicates.data)
+                raise GenieException('Unknown instruction: %s' % predicates.data)
         return results
 
 
     def _run(self, pt: Tree) -> List[Tuple[str, bool]]:
-        for instruction in pt.children:
-            if instruction.data == "predicates":
-                return self._apply_predicates(instruction.children)
-            else:
-                raise SyntaxError('Unknown instruction: %s' % instruction.data)
+        if len(pt.children) != 1:
+            raise GenieException('How is this possible: %s' % pt.children)
+
+        instruction = pt.children[0]
+        if instruction.data == "predicates":
+            return self._apply_predicates(instruction.children)
+        else:
+            raise GenieException('Unknown instruction: %s' % instruction.data)
 
 
     @staticmethod
